/*********************************************************************
 * Copyright (c) 2004, 2007 Boeing
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     Boeing - initial API and implementation
 **********************************************************************/

package org.eclipse.osee.ote.core.environment.command;

import java.io.Serializable;
import org.eclipse.osee.framework.jdk.core.util.GUID;

/**
 * @author Robert A. Fisher
 */
public class CommandDescription implements Serializable {
   private static final long serialVersionUID = 538355585678229304L;
   protected final String guid;
   protected final String description;

   /**
    * CommandDescription Constructor. Sets the command's description.
    */
   public CommandDescription(String description) {
      super();
      this.guid = GUID.create();
      this.description = description;
   }

   /**
    * @return Returns the description.
    */
   public String getDescription() {
      return description;
   }

   @Override
   public boolean equals(Object obj) {

      if (obj instanceof GUID) {
         return guid.equals(obj);
      } else if (obj instanceof CommandDescription) {
         return guid.equals(((CommandDescription) obj).guid);
      }

      return false;
   }

   /**
    * @return Returns the guid.
    */
   public String getGuid() {
      return guid;
   }

   @Override
   public String toString() {
      return "GUID: " + guid + "\n" + "Desc: " + description;
   }
}
