/*********************************************************************
 * Copyright (c) 2004, 2007 Boeing
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     Boeing - initial API and implementation
 **********************************************************************/

package org.eclipse.osee.ote.core.environment.interfaces;

import java.lang.reflect.Constructor;
import org.eclipse.osee.ote.core.environment.TestEnvironment;

public interface ITestEnvironmentServiceConfig {
   /**
    * gets the maximum number of environments allowed in this service
    */
   public int getMaxEnvironments();

   public int getMaxUsersPerEnvironment();

   public String getName();

   public String getServerTitle();

   public String getOutfileLocation();

   /**
    * gets the Constructor for the creating new environments
    */
   public Constructor<? extends TestEnvironment> getEnvironmentConstructor();

   /**
    * gets the parameter instances need to calling the constructor when new environments are created
    */
   public Object[] getConstructorParameters();

   /**
    * tells whether the environment should stay running when the last user disconnects
    * 
    * @return true if the environment should stay active when no users are connected or false otherwise
    */
   public boolean keepEnvAliveWithNoUsers();

   /**
    * returns whether an environment should be created and started up upon service initialization
    * 
    * @return true if an environment should be started up or false if no evionment should be created until requested
    */
   public boolean startEnvionrmnetOnServiceInit();
}
