/*********************************************************************
 * Copyright (c) 2004, 2007 Boeing
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     Boeing - initial API and implementation
 **********************************************************************/

package org.eclipse.osee.ote.message.elements;

import java.nio.ByteBuffer;
import java.util.Collection;
import org.eclipse.osee.ote.message.Message;
import org.eclipse.osee.ote.message.data.MemoryResource;
import org.eclipse.osee.ote.message.data.MessageData;

public class ArrayElement extends Element {

   public ArrayElement(Message msg, String elementName, MessageData messageData, int byteOffset, int msb, int lsb, int originalMsb, int originalLsb) {
      super(msg, elementName, messageData, byteOffset, msb, lsb, originalMsb, originalLsb);
   }

   public ArrayElement(Message msg, String elementName, MessageData messageData, int bitOffset, int bitLength) {
      super(msg, elementName, messageData, bitOffset, bitLength);
   }

   public ArrayElement(Message msg, String elementName, MessageData messageData, int byteOffset, int msb, int lsb) {
      super(msg, elementName, messageData, byteOffset, msb, lsb);
   }

   @Override
   protected Element getNonMappingElement() {
      return null;
   }

   public void setValue(int index, byte value) {
      getMsgData().getMem().getData()[index + getMsgData().getMem().getOffset() + getArrayStartOffset()] = value;
   }

   public ByteBuffer asByteBuffer() {
      return ByteBuffer.wrap(getMsgData().getMem().getData(),
         getMsgData().getMem().getOffset() + getArrayStartOffset(), getLength());
   }

   public byte getValue(int index) {
      return getValue(getMsgData().getMem(), index);
   }

   public byte getValue(MemoryResource mem, int index) {
      return mem.getData()[index + mem.getOffset() + getArrayStartOffset()];

   }

   @Override
   public void zeroize() {
      MemoryResource mem = getMsgData().getMem();
      mem.zeroizeFromOffset(getArrayStartOffset(), getLength());
   }

   public int getLength() {
      int currentMsgLength = getMsgData().getCurrentLength() - getMsgData().getOffset() - getArrayStartOffset();
      int length = getArrayEndOffset() - getArrayStartOffset();
      length = currentMsgLength < length ? currentMsgLength : length;
      return length;
   }

   public int getArrayStartOffset() {
      return byteOffset + msb / 8;
   }

   public int getArrayEndOffset() {
      return (lsb - msb + 1) / 8 + byteOffset;
   }

   @Override
   public void visit(IElementVisitor visitor) {
      visitor.asArrayElement(this);
   }

   @Override
   public ArrayElement findElementInMessages(Collection<? extends Message> messages) {
      return (ArrayElement) super.findElementInMessages(messages);
   }
   
   @Override
   public ArrayElement switchMessages(Collection<? extends Message> messages) {
      return (ArrayElement) super.switchMessages(messages);
   }

}
